# Support

## Documentation

Full documentation is available at [thatdevstudio.github.io/ztlctl](https://thatdevstudio.github.io/ztlctl/) and in the [docs/](docs/) folder.

## Getting Help

1. Check the [Troubleshooting Guide](docs/troubleshooting.md) for common issues
2. Search [existing issues](https://github.com/ThatDevStudio/ztlctl/issues) to see if your question has been answered
3. Open a [new issue](https://github.com/ThatDevStudio/ztlctl/issues/new/choose) if you need further assistance

## Reporting Bugs

Use the [Bug Report](https://github.com/ThatDevStudio/ztlctl/issues/new?template=bug_report.yml) template to file a bug. Include your ztlctl version (`ztlctl --version`), Python version, and steps to reproduce.

## Security Issues

Do not open public issues for security vulnerabilities. See [SECURITY.md](SECURITY.md) for responsible disclosure instructions.
